clarite.survey.SurveyDesignSpec
===============================

.. currentmodule:: clarite.survey

.. autoclass:: SurveyDesignSpec

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SurveyDesignSpec.__init__
      ~SurveyDesignSpec.get_survey_design
      ~SurveyDesignSpec.validate_params
   
   

   
   
   